@@ -1,5 +1,5 @@
 # Retrieves character data
-Q_CHARACTER_DATA = """
+Q_CHARACTER_DATA = '''
 query {{
     characterData {{
         character({filters}) {{
@@ -7,4 +7,4 @@ query {{
         }}
     }}
 }}
-"""
+'''
